@@ -1,8 +1,8 @@
-# $Id: install.py 998 2014-08-15 03:16:34Z mwall $
+# $Id: install.py 1237 2015-02-02 03:22:06Z mwall $
 # installer for simple
 # Copyright 2014 Matthew Wall
 
-from setup import SimpleInstaller
+from setup import ExtensionInstaller
 
 def loader():
     return SimpleInstaller()
@@ -10,8 +10,8 @@ def loader():
 class SimpleInstaller(ExtensionInstaller):
     def __init__(self):
         super(SimpleInstaller, self).__init__(
-            version="0.3",
-            name='exfoliation',
+            version="0.4",
+            name='simple',
             description='A minimalist layout.',
             author="Matthew Wall",
             author_email="mwall@users.sourceforge.net",
